@@ -9,8 +9,8 @@ admin.autodiscover()
 urlpatterns = patterns('',
     (r'^media/(?P<path>.+)$', 'django.views.static.serve', {'document_root': settings._BASE_DIR + '/media'}),
     (r'^admin/', include(admin.site.urls)),
+    (r'^blog/?', include(gitcms.blog.urls)),
 )
-urlpatterns += gitcms.blog.urls.urlpatterns
 urlpatterns += gitcms.files.urls.urlpatterns
 urlpatterns += gitcms.simplecms.urls.urlpatterns
 
